@@ -47,12 +47,7 @@ fn main() {
                         reverse_dependencies
                     );
 
-                    let cache = PathBuf::from(concat!(
-                        "/tmp/",
-                        env!("CARGO_PKG_NAME"),
-                        "-",
-                        env!("CARGO_PKG_VERSION")
-                    ));
+                    let cache = PathBuf::from(concat!("/tmp/", env!("CARGO_PKG_NAME"),));
 
                     if !cache.exists() {
                         match create_dir_all(&cache) {
@@ -273,6 +268,7 @@ fn main() {
                     }
 
                     statistics.report();
+                    exit(statistics.get_exit_code());
                 }
                 Err(_) => {
                     error!(
